@@ -16,44 +16,10 @@ def auth_required(view_function):
         Authenticates request before invoking dispatch_request
         of target view.
     """
-    response_dict = {"success": 0}
-
-    user_id, id_token = auth.get_user_id_and_token()
-    auth_type = auth.get_auth_type()
-    if is_dashboard_url() and not (user_id and id_token):
-      return dashboard_login_page()
-
-    if not user_id:
-      response_dict["error_message"] = "UNAUTHORIZED USER"
-      return jsonify(response_dict), 401
-
-    if not id_token:
-      response_dict["error_message"] = "UNAUTHORIZED TOKEN"
-      return jsonify(response_dict), 401
-
-    auth_ob = auth.Auth(id_token, user_id)
-    error = ''
-    # pragma pylint: disable=broad-except
-    try:
-      auth_result = auth_ob.authorize_request(auth_type=auth_type)
-    except Exception as e:
-      error = e
-      auth_result = None
-
-    if not auth_result:
-      error = "Unauthorised login for web request found"
-      if is_dashboard_url():
-        g.app.logger.warning(error)
-        session.pop("gae_uid", None)
-        return dashboard_login_page()
-
-      response_dict["error_message"] = str(error)
-      return jsonify(response_dict), 401
-
-    uid_filter = ('uid', '=', user_id)
-    user = User.retrieve(filters=[uid_filter])[0]
-    g.user_key = user.key().id
-    return view_function(*args, **kwargs)
+    authentication_response = perform_authentication()
+    if authentication_response == True:
+      return view_function(*args, **kwargs)
+    return authentication_response
 
   # The following if block is required to avoid different
   # view functions getting mapped to the same endpoint name
@@ -72,6 +38,47 @@ def auth_required(view_function):
   return decorator
 
 
+def perform_authentication():
+  # Returns True if authentication is successful, otherwise return relevant json response or redirect
+  response_dict = {"success": 0}
+  user_id, id_token = auth.get_user_id_and_token()
+  auth_type = auth.get_auth_type()
+  if is_dashboard_url() and not (user_id and id_token):
+    return dashboard_login_page()
+
+  if not user_id:
+    response_dict["error_message"] = "UNAUTHORIZED USER"
+    return jsonify(response_dict), 401
+
+  if not id_token:
+    response_dict["error_message"] = "UNAUTHORIZED TOKEN"
+    return jsonify(response_dict), 401
+
+  auth_ob = auth.Auth(id_token, user_id)
+  error = ''
+  # pragma pylint: disable=broad-except
+  try:
+    auth_result = auth_ob.authorize_request(auth_type=auth_type)
+  except Exception as e:
+    error = e
+    auth_result = None
+
+  if not auth_result:
+    error = "Unauthorised login for web request found"
+    if is_dashboard_url():
+      g.app.logger.warning(error)
+      session.pop("gae_uid", None)
+      return dashboard_login_page()
+
+    response_dict["error_message"] = str(error)
+    return jsonify(response_dict), 401
+
+  uid_filter = ('uid', '=', user_id)
+  user = User.retrieve(filters=[uid_filter])[0]
+  g.user_key = user.key().id
+  return True
+
+
 def verification_required(view_function):
   """
       Function to be used with as_view().
