@@ -17,5 +17,20 @@ ACCOUNT_SID = ''
 AUTH_TOKEN = ''
 TOKEN_LENGTH = 12
 
-# APNS Settings
+# Firebase Notifications Settings
 AUTH0_JKWS_DOMAIN = ''
+APNS_KEY_ID = ''
+APNS_TEAM_ID = ''
+APNS_AUTH_KEY_PATH = ''
+IOS_BUNDLE_ID = ''
+
+# Task Queues
+TASK_QUEUE_STAGING = {
+    'queue_name': 'notifications-rev2',
+    'location': 'us-central1'}
+TASK_QUEUE_PROD = {
+    'queue_name': 'TBD',
+    'location': 'TBD'}
+
+# Notification Task Constants
+MAX_NOTIFICATION_TASK_RETRIES = 5
\ No newline at end of file
