@@ -32,12 +32,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
   def test_when_authorization_is_present_with_both_user_id_and_id_token_and_auth_type_is_not_present_and_user_already_exists(self):
     headers = {
@@ -53,13 +53,13 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user_response = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
-    self.assertEquals(user.key().id, data['id'])
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
+    self.assertEqual(user.key().id, data['id'])
 
 
   def test_when_authorization_is_present_with_both_user_id_and_id_token_and_auth_type_is_firebase_and_user_does_not_exist(self):
@@ -75,12 +75,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=firebase', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_authorization_is_present_with_both_user_id_and_id_token_and_auth_type_is_firebase_and_user_already_exists(self):
@@ -97,13 +97,13 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=firebase', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user_response = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
-    self.assertEquals(user.key().id, data['id'])
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
+    self.assertEqual(user.key().id, data['id'])
 
 
   def test_when_authorization_is_present_with_both_user_id_and_id_token_and_auth_type_is_auth_0_and_user_does_not_exist(self):
@@ -119,12 +119,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.auth0_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=auth0', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_authorization_is_present_with_both_user_id_and_id_token_and_auth_type_is_auth_0_and_user_already_exists(self):
@@ -141,13 +141,13 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.auth0_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=auth0', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user_response = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
-    self.assertEquals(user.key().id, data['id'])
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
+    self.assertEqual(user.key().id, data['id'])
 
 
   def test_when_authorization_is_present_with_both_user_id_and_id_token_and_auth_type_is_not_present_and_user_does_not_exist(self):
@@ -163,12 +163,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_authorization_is_present_with_user_id_and_auth_type_is_not_present(self):
@@ -184,9 +184,9 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals("NO_ID_TOKEN", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual("NO_ID_TOKEN", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_when_authorization_is_present_with_id_token_and_auth_type_is_not_present(self):
     headers = {
@@ -201,10 +201,10 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals("NO USER_ID", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
-    self.assertEquals(0, self.get_entity_count('Player'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual("NO USER_ID", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
+    self.assertEqual(0, self.get_entity_count('Player'))
 
   def test_when_authorization_is_not_present_and_auth_type_is_not_present(self):
     claims = {
@@ -216,9 +216,9 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals("NO USER_ID", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual("NO USER_ID", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_not_present_and_user_does_not_exist(self):
     claims = {
@@ -233,12 +233,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
       sess['gae_token'] = 'token'
     response = self.client.post('/login/')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_not_present_and_user_already_exists(self):
@@ -255,13 +255,13 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
       sess['gae_token'] = 'token'
     response = self.client.post('/login/')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user_response = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
-    self.assertEquals(user.key().id, data['id'])
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
+    self.assertEqual(user.key().id, data['id'])
 
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_firebase_and_user_does_not_exist(self):
@@ -277,12 +277,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
       sess['gae_token'] = 'token'
     response = self.client.post('/login/?auth_type=firebase')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_firebase_and_user_already_exists(self):
@@ -299,13 +299,13 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=firebase')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user_response = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
-    self.assertEquals(user.key().id, data['id'])
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
+    self.assertEqual(user.key().id, data['id'])
 
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_auth_0_and_user_does_not_exist(self):
@@ -321,12 +321,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.auth0_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=auth0')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_auth_0_and_user_already_exists(self):
@@ -343,13 +343,13 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.auth0_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=auth0')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user_response = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
-    self.assertEquals(user.key().id, data['id'])
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
+    self.assertEqual(user.key().id, data['id'])
 
 
   def test_when_session_is_present_with_both_user_id_and_id_token_and_auth_type_is_not_present_and_user_does_not_exist(self):
@@ -365,12 +365,12 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
+    self.assertEqual(202, response.status_code)
     user = User(key_str=data['id'])
     self.assertIsNotNone(user)
-    self.assertEquals(data["uId"], user.uid)
-    self.assertEquals(data["name"], user.name)
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(data["uId"], user.uid)
+    self.assertEqual(data["name"], user.name)
+    self.assertEqual(1, self.get_entity_count('User'))
 
 
   def test_when_session_is_present_with_user_id_and_auth_type_is_not_present(self):
@@ -385,9 +385,9 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals("NO_ID_TOKEN", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual("NO_ID_TOKEN", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_when_session_is_present_with_id_token_and_auth_type_is_not_present(self):
     claims = {
@@ -401,9 +401,9 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/')
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals("NO USER_ID", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual("NO USER_ID", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_when_claims_is_empty_and_auth_type_is_firebase(self):
     headers = {
@@ -413,9 +413,9 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(401, response.status_code)
-    self.assertEquals("EMPTY_CLAIM", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(401, response.status_code)
+    self.assertEqual("EMPTY_CLAIM", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_when_claims_is_empty_and_auth_type_is_auth0(self):
     headers = {
@@ -425,9 +425,9 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.auth0_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=auth0', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(401, response.status_code)
-    self.assertEquals("EMPTY_CLAIM", data["error_message"])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(401, response.status_code)
+    self.assertEqual("EMPTY_CLAIM", data["error_message"])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_for_provider_when_auth_type_is_firebase(self):
     headers = {
@@ -442,8 +442,8 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.firebase_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=firebase', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
-    self.assertEquals(data["provider"], 'google')
+    self.assertEqual(202, response.status_code)
+    self.assertEqual(data["provider"], 'google')
 
   def test_for_provider_when_auth_type_is_auth0(self):
     headers = {
@@ -458,8 +458,8 @@ class LoginViewTestCase(BaseAuthUnitTestCase):
     self.auth0_authorize.return_value = claims
     response = self.client.post('/login/?auth_type=auth0', headers=headers)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(202, response.status_code)
-    self.assertEquals(data["provider"], 'apple')
+    self.assertEqual(202, response.status_code)
+    self.assertEqual(data["provider"], 'apple')
 
 
 class VerificationTestCase(BaseAuthUnitTestCase):
@@ -481,36 +481,36 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.send_verification_code.return_value = "NOT_NONE"
     response = self.client.get("/verification/?phone=1234", json=self.auth_type_json)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(200, response.status_code)
-    self.assertEquals('success', data['status'])
+    self.assertEqual(200, response.status_code)
+    self.assertEqual('success', data['status'])
 
   def test_verification_when_verifying_with_phone_and_verification_code_is_not_sent(self):
     self.send_verification_code.return_value = None
     response = self.client.get("/verification/?phone=1234", json=self.auth_type_json)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('Error while sending verification code', data['error_message'])
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('Error while sending verification code', data['error_message'])
 
   def test_verification_when_verifying_with_email_and_verification_code_is_sent(self):
     self.send_verification_code.return_value = "NOT_NONE"
     response = self.client.get("/verification/?email=abcd", json=self.auth_type_json)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(200, response.status_code)
-    self.assertEquals('success', data['status'])
+    self.assertEqual(200, response.status_code)
+    self.assertEqual('success', data['status'])
 
   def test_verification_when_verifying_with_email_and_verification_code_is_not_sent(self):
     self.send_verification_code.return_value = None
     response = self.client.get("/verification/?email=abcd", json=self.auth_type_json)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('Error while sending verification code', data['error_message'])
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('Error while sending verification code', data['error_message'])
 
   def test_verification_when_verifying_with_no_method_and_verification_code_is_not_sent(self):
     self.send_verification_code.return_value = None
     response = self.client.get("/verification/", json=self.auth_type_json)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('No phone number or e-mail specified', data['error_message'])
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('No phone number or e-mail specified', data['error_message'])
 
   def test_verification_when_verifying_with_phone_and_correct_code_and_user_does_not_exist(self):
     form_data = {
@@ -521,12 +521,12 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'success'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(200, response.status_code)
+    self.assertEqual(200, response.status_code)
     self.assertIsNotNone(data['token'])
-    self.assertEquals('success', data['status'])
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual('success', data['status'])
+    self.assertEqual(1, self.get_entity_count('User'))
     user = User.retrieve(filters=[('token', '=', data['token'])])[0]
-    self.assertEquals('1234', user.phone)
+    self.assertEqual('1234', user.phone)
 
 
   def test_verification_when_verifying_with_phone_and_correct_code_and_user_exists(self):
@@ -539,13 +539,13 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'success'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(200, response.status_code)
+    self.assertEqual(200, response.status_code)
     self.assertIsNotNone(data['token'])
-    self.assertEquals('success', data['status'])
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual('success', data['status'])
+    self.assertEqual(1, self.get_entity_count('User'))
     user_resp = User.retrieve(filters=[('token', '=', data['token'])])[0]
-    self.assertEquals('1234', user_resp.phone)
-    self.assertEquals(user.key().id, user_resp.key().id)
+    self.assertEqual('1234', user_resp.phone)
+    self.assertEqual(user.key().id, user_resp.key().id)
 
 
   def test_verification_when_verifying_with_phone_and_incorrect_code_and_user_does_not_exist(self):
@@ -557,9 +557,9 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'failure'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('Incorrect Code', data['error_message'])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('Incorrect Code', data['error_message'])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_verification_when_verifying_with_phone_and_incorrect_code_and_user_exists(self):
     form_data = {
@@ -571,9 +571,9 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'failure'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('Incorrect Code', data['error_message'])
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('Incorrect Code', data['error_message'])
+    self.assertEqual(1, self.get_entity_count('User'))
 
   def test_verification_when_verifying_with_email_and_correct_code_and_user_does_not_exist(self):
     form_data = {
@@ -584,12 +584,12 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'success'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(200, response.status_code)
+    self.assertEqual(200, response.status_code)
     self.assertIsNotNone(data['token'])
-    self.assertEquals('success', data['status'])
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual('success', data['status'])
+    self.assertEqual(1, self.get_entity_count('User'))
     user = User.retrieve(filters=[('token', '=', data['token'])])[0]
-    self.assertEquals('1234', user.email)
+    self.assertEqual('1234', user.email)
     self.assertIsNone(user.phone)
 
 
@@ -603,14 +603,14 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'success'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(200, response.status_code)
+    self.assertEqual(200, response.status_code)
     self.assertIsNotNone(data['token'])
-    self.assertEquals('success', data['status'])
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual('success', data['status'])
+    self.assertEqual(1, self.get_entity_count('User'))
     user_resp = User.retrieve(filters=[('token', '=', data['token'])])[0]
-    self.assertEquals('1234', user_resp.email)
+    self.assertEqual('1234', user_resp.email)
     self.assertIsNone(user_resp.phone)
-    self.assertEquals(user.key().id, user_resp.key().id)
+    self.assertEqual(user.key().id, user_resp.key().id)
 
 
   def test_verification_when_verifying_with_email_and_incorrect_code_and_user_does_not_exist(self):
@@ -622,9 +622,9 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'failure'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('Incorrect Code', data['error_message'])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('Incorrect Code', data['error_message'])
+    self.assertEqual(0, self.get_entity_count('User'))
 
   def test_verification_when_verifying_with_email_and_incorrect_code_and_user_exists(self):
     form_data = {
@@ -636,9 +636,9 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     self.check_verification.return_value = 'failure'
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('Incorrect Code', data['error_message'])
-    self.assertEquals(1, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('Incorrect Code', data['error_message'])
+    self.assertEqual(1, self.get_entity_count('User'))
 
   def test_verification_when_verifying_with_no_method(self):
     form_data = {
@@ -647,9 +647,9 @@ class VerificationTestCase(BaseAuthUnitTestCase):
     }
     response = self.client.post('/verification/', data=form_data)
     data = json.loads(response.get_data(as_text=True))
-    self.assertEquals(400, response.status_code)
-    self.assertEquals('No Phone Number', data['error_message'])
-    self.assertEquals(0, self.get_entity_count('User'))
+    self.assertEqual(400, response.status_code)
+    self.assertEqual('No Phone Number', data['error_message'])
+    self.assertEqual(0, self.get_entity_count('User'))
 
 class ViewsTestCase(BaseAuthUnitTestCase):
 
@@ -658,9 +658,9 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       user = views.check_for_new_user_with_uid(g.app.logger, 'user_id', {'name': 'user', 'email': 'user@cc'}, None)
       self.assertIsNotNone(user)
-      self.assertEquals(1, self.get_entity_count('User'))
-      self.assertEquals('user_id', user.uid)
-      self.assertEquals('user', user.name)
+      self.assertEqual(1, self.get_entity_count('User'))
+      self.assertEqual('user_id', user.uid)
+      self.assertEqual('user', user.name)
 
   def test_check_for_new_user_if_device_token_updated_with_uid_when_new_user(self):
     device_token_data = {
@@ -670,23 +670,23 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       user = views.check_for_new_user_with_uid(g.app.logger, 'user_id', {'name': 'user', 'email': 'user@cc'}, device_token_data)
       self.assertIsNotNone(user)
-      self.assertEquals(1, self.get_entity_count('User'))
-      self.assertEquals('user_id', user.uid)
-      self.assertEquals('user', user.name)
-      self.assertEquals('test_token', user.device_notification_token)
-      self.assertEquals('test_os', user.os)
+      self.assertEqual(1, self.get_entity_count('User'))
+      self.assertEqual('user_id', user.uid)
+      self.assertEqual('user', user.name)
+      self.assertEqual('test_token', user.device_notification_token)
+      self.assertEqual('test_os', user.os)
 
   def test_check_for_new_user_when_existing_user(self):
     with self.tests_app.test_request_context():
       self.tests_app.preprocess_request()
       user = self.add_user_entity(uid='user_id')
-      self.assertEquals(1, self.get_entity_count('User'))
+      self.assertEqual(1, self.get_entity_count('User'))
       user_resp = views.check_for_new_user_with_uid(g.app.logger, 'user_id', {'name': 'user', 'email': 'user@cc'}, None)
       self.assertIsNotNone(user)
-      self.assertEquals(1, self.get_entity_count('User'))
-      self.assertEquals(user.key().id, user_resp.key().id)
-      self.assertEquals('user_id', user_resp.uid)
-      self.assertEquals('user', user_resp.name)
+      self.assertEqual(1, self.get_entity_count('User'))
+      self.assertEqual(user.key().id, user_resp.key().id)
+      self.assertEqual('user_id', user_resp.uid)
+      self.assertEqual('user', user_resp.name)
 
   def test_check_for_new_user_if_device_token_updated_when_existing_user(self):
     device_token_data = {
@@ -695,15 +695,15 @@ class ViewsTestCase(BaseAuthUnitTestCase):
     with self.tests_app.test_request_context():
       self.tests_app.preprocess_request()
       user = self.add_user_entity(uid='user_id')
-      self.assertEquals(1, self.get_entity_count('User'))
+      self.assertEqual(1, self.get_entity_count('User'))
       user_resp = views.check_for_new_user_with_uid(g.app.logger, 'user_id', {'name': 'user', 'email': 'user@cc'}, device_token_data)
       self.assertIsNotNone(user)
-      self.assertEquals(1, self.get_entity_count('User'))
-      self.assertEquals(user.key().id, user_resp.key().id)
-      self.assertEquals('user_id', user_resp.uid)
-      self.assertEquals('user', user_resp.name)
-      self.assertEquals('test_token', user_resp.device_notification_token)
-      self.assertEquals('test_os', user_resp.os)
+      self.assertEqual(1, self.get_entity_count('User'))
+      self.assertEqual(user.key().id, user_resp.key().id)
+      self.assertEqual('user_id', user_resp.uid)
+      self.assertEqual('user', user_resp.name)
+      self.assertEqual('test_token', user_resp.device_notification_token)
+      self.assertEqual('test_os', user_resp.os)
 
   def test_check_for_new_user_with_phone_or_email_with_phone_or_email_when_new_user_and_method_is_phone(self):
     user = self.add_user_entity(phone='0183409112', token='abc')
@@ -712,8 +712,8 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       result = views.check_for_new_user_with_phone_or_email(
           g.app.logger, '0183409', None, None)
       self.assertIsNotNone(result)
-      self.assertEquals('0183409', result.phone)
-      self.assertEquals(0, result.role)
+      self.assertEqual('0183409', result.phone)
+      self.assertEqual(0, result.role)
 
   def test_check_for_new_user_with_phone_or_email_with_phone_or_email_when_new_user_and_method_is_email(self):
     user = self.add_user_entity(email='email123@abc.com', token='abc')
@@ -721,8 +721,8 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, None, 'email@abc.com', None)
       self.assertIsNotNone(result)
-      self.assertEquals('email@abc.com', result.email)
-      self.assertEquals(0, result.role)
+      self.assertEqual('email@abc.com', result.email)
+      self.assertEqual(0, result.role)
 
   def test_check_for_new_user_when_new_user_and_method_is_None(self):
     with self.tests_app.test_request_context():
@@ -736,8 +736,8 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, '0183409', None, None)
       self.assertIsNotNone(result)
-      self.assertEquals('0183409', result.phone)
-      self.assertEquals(user.key().id, result.key().id)
+      self.assertEqual('0183409', result.phone)
+      self.assertEqual(user.key().id, result.key().id)
       self.assertNotEquals(user.token, result.token)
 
   def test_check_for_new_user_with_phone_or_email_when_existing_user_and_method_is_email(self):
@@ -746,8 +746,8 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, None, 'email@abc.com', None)
       self.assertIsNotNone(result)
-      self.assertEquals('email@abc.com', result.email)
-      self.assertEquals(user.key().id, result.key().id)
+      self.assertEqual('email@abc.com', result.email)
+      self.assertEqual(user.key().id, result.key().id)
       self.assertNotEquals(user.token, result.token)
 
   def test_check_for_new_user_with_phone_or_email_if_device_token_updated_when_existing_user_and_method_is_email(self):
@@ -759,10 +759,10 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, None, 'email@abc.com', device_token_data)
       self.assertIsNotNone(result)
-      self.assertEquals('email@abc.com', result.email)
-      self.assertEquals(user.key().id, result.key().id)
-      self.assertEquals(result.os, 'test_os')
-      self.assertEquals(result.device_notification_token, 'test_token')
+      self.assertEqual('email@abc.com', result.email)
+      self.assertEqual(user.key().id, result.key().id)
+      self.assertEqual(result.os, 'test_os')
+      self.assertEqual(result.device_notification_token, 'test_token')
       self.assertNotEquals(user.token, result.token)
   
   def test_check_for_new_user_with_phone_or_email_if_device_token_updated_when_existing_user_and_method_is_phone(self):
@@ -774,10 +774,10 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, '12345', None, device_token_data)
       self.assertIsNotNone(result)
-      self.assertEquals('12345', result.phone)
-      self.assertEquals(user.key().id, result.key().id)
-      self.assertEquals(result.os, 'test_os')
-      self.assertEquals(result.device_notification_token, 'test_token')
+      self.assertEqual('12345', result.phone)
+      self.assertEqual(user.key().id, result.key().id)
+      self.assertEqual(result.os, 'test_os')
+      self.assertEqual(result.device_notification_token, 'test_token')
       self.assertNotEquals(user.token, result.token)
 
   def test_check_for_new_user_with_phone_or_email_if_device_token_updated_when_not_existing_user_and_method_is_email(self):
@@ -788,9 +788,9 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, None, 'email@abc.com', device_token_data)
       self.assertIsNotNone(result)
-      self.assertEquals('email@abc.com', result.email)
-      self.assertEquals(result.os, 'test_os')
-      self.assertEquals(result.device_notification_token, 'test_token')
+      self.assertEqual('email@abc.com', result.email)
+      self.assertEqual(result.os, 'test_os')
+      self.assertEqual(result.device_notification_token, 'test_token')
   
   def test_check_for_new_user_with_phone_or_email_if_device_token_updated_when_not_existing_user_and_method_is_phone(self):
     device_token_data = {
@@ -800,17 +800,17 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, '12345', None, device_token_data)
       self.assertIsNotNone(result)
-      self.assertEquals('12345', result.phone)
-      self.assertEquals(result.os, 'test_os')
-      self.assertEquals(result.device_notification_token, 'test_token')
+      self.assertEqual('12345', result.phone)
+      self.assertEqual(result.os, 'test_os')
+      self.assertEqual(result.device_notification_token, 'test_token')
 
   def test_check_for_new_user_with_phone_or_email_for_profile_picture_when_not_existing_user(self):
     with self.tests_app.test_request_context():
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, '12345', None, None)
       self.assertIsNotNone(result)
-      self.assertEquals('12345', result.phone)
-      self.assertEquals('https://storage.googleapis.com/crypticcup-images/default_profile.jpg', result.picture)
+      self.assertEqual('12345', result.phone)
+      self.assertEqual('https://storage.googleapis.com/crypticcup-images/default_profile.jpg', result.picture)
 
   def test_check_for_new_user_with_phone_or_email_for_profile_picture_when_existing_user(self):
     user = self.add_user_entity(phone='12345', token='abc', picture='picture@')
@@ -818,8 +818,8 @@ class ViewsTestCase(BaseAuthUnitTestCase):
       self.tests_app.preprocess_request()
       result = views.check_for_new_user_with_phone_or_email(g.app.logger, '12345', None, None)
       self.assertIsNotNone(result)
-      self.assertEquals('12345', result.phone)
-      self.assertEquals('picture@', result.picture)
+      self.assertEqual('12345', result.phone)
+      self.assertEqual('picture@', result.picture)
 
   def test_check_for_new_user_when_auth_type_is_verify(self):
     self.mock_check_for_new_user_with_phone_or_email()
