@@ -5,11 +5,11 @@ from google.cloud import datastore
 from mock import patch
 
 
-
 class BaseUnitTestCase(unittest.TestCase):
 
   tests_app = web.startup(parameter_logging=True,
-                        client_logging=True)
+                          client_logging=True)
+
   def setUp(self):
     self.tests_app.testing = True
     self.client = self.tests_app.test_client()
@@ -34,6 +34,13 @@ class BaseUnitTestCase(unittest.TestCase):
       for i in range(0, len(keys), 499):
         client.delete_multi(keys[i:i + 499])
 
+  def get_entity_count(self, kind):
+    client = datastore.Client(namespace=helpers.get_datastore_namespace())
+    query = client.query(kind=kind)
+    query.keys_only()
+    keys = [entity.key for entity in query.fetch()]
+    return len(keys)
+
   def mock_storage_client(self):
     self.storage_client_patch = patch(
         'google.cloud.storage.Client')
