@@ -2,6 +2,7 @@ from gaelib.tests.base import BaseUnitTestCase
 from gaelib.cron.decorators import cron_validate
 from werkzeug.exceptions import HTTPException
 from mock import Mock
+import json
 
 
 class DecoratorsTestCase(BaseUnitTestCase):
@@ -18,7 +19,10 @@ class DecoratorsTestCase(BaseUnitTestCase):
   def check_exception(self):
     self.tests_app.preprocess_request()
     decorated_func = cron_validate(Mock())
-    self.assertRaises(HTTPException, decorated_func)
+    response, status = decorated_func()
+    data = json.loads(response.get_data(as_text=True))
+    self.assertEqual(data["error_message"], "Cron Validation Failed!")
+    self.assertEqual(status, 400)
 
   def test_cron_validate_when_ip_is_not_valid(self):
     environ_dict = {
