@@ -104,7 +104,7 @@ class ModelUnitTestCase(BaseUnitTestCase):
         for obj in q.fetch():
             self.assertGreaterEqual(last_value,obj.int1, "Failed to order items in result")
             last_value = obj.int1
-        self.assertEquals(len(q.fetch()), 2, "Failed to fetch. Fetched {} instead of 2 items".format(len(q.fetch())))
+        self.assertEqual(len(q.fetch()), 2, "Failed to fetch. Fetched {} instead of 2 items".format(len(q.fetch())))
 
     def test_retrieve(self):
         model = Test(key_str = 'record1', string1 = '123', string2 = '456', int1 = 111)
@@ -120,7 +120,7 @@ class ModelUnitTestCase(BaseUnitTestCase):
 
         #testing for key_str        
         items = model.retrieve(key_strs = ['record1'])
-        self.assertEquals(items[0].int1, 111, "Failed to retrieve using key_str")
+        self.assertEqual(items[0].int1, 111, "Failed to retrieve using key_str")
 
         #testing for filters, order and limit
         limit = 2
@@ -128,7 +128,7 @@ class ModelUnitTestCase(BaseUnitTestCase):
         last_value = 200
         for obj in items:
             self.assertGreater(obj.int1, 111, "Failed to apply filter")
-            self.assertEquals(obj.string1,'123', "Failed to apply filter")
+            self.assertEqual(obj.string1,'123', "Failed to apply filter")
             self.assertGreaterEqual(last_value,obj.int1, "Failed to order items")
             last_value = obj.int1
-        self.assertEquals(len(items),limit, "Failed to apply limit. Fetched {} instead of {} items".format(len(items),limit))
+        self.assertEqual(len(items),limit, "Failed to apply limit. Fetched {} instead of {} items".format(len(items),limit))
