@@ -16,6 +16,13 @@ auth_urls.add_url_rule(
     view_func=LazyView('gaelib.auth.views.Login', 'login'),
     methods=['POST'])
 
+task_urls = Blueprint('task', __name__)
+task_urls.add_url_rule(
+    '/notification_task_handler/',
+    view_func=LazyView(
+        'gaelib.tasks.notification_task.NotificationTask', 'notification_task'),
+    methods=['POST'])
+
 verification_urls = Blueprint('verification', __name__)
 verification_urls.add_url_rule(
     '/verification/',
